==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/pub/PubContactOrg.md <==
select
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.ORG_TYPE,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		GETDICNAME('ORG_TYPE', t.ORG_TYPE) AS ORG_TYPE_TEXT,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		type.ORG_TYPE type_org_type,
		t.IS_INNER_ORG,
		t.TYPE,
		t.CONTACT_TYPE,
		GETDICNAME('CONTACT_TYPE',t.CONTACT_TYPE) AS CONTACT_TYPE_TEXT,
		t.INNER_ORG_ID,
		TYPE.CONTACT_ORG_TYPE_NAME as  TYPE_NAME 
	 @}
from PUB_CONTACT_ORG t
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
where t.is_use = 'Y'
 @if(!isEmpty(contactOrgTypeId)){
AND (t.contact_org_type_id = #contactOrgTypeId# or
            t.CONTACT_ORG_TYPE_ID in
           (with recursive tmp as 
(select A.CONTACT_ORG_TYPE_ID  from PUB_CONTACT_ORG_TYPE A where A.contact_org_type_pid = #contactOrgTypeId#
UNION ALL 
select B.CONTACT_ORG_TYPE_ID from PUB_CONTACT_ORG_TYPE B,tmp t  where t.CONTACT_ORG_TYPE_ID = B.CONTACT_ORG_TYPE_PID) 
select *  from tmp p))
@}
@if(!isEmpty(type)){
and t.type =#type#
@}
@if(!isEmpty(contactType)){
and t.CONTACT_TYPE =#contactType#
@}
@if(!isEmpty(search)){
and(
 upper(t.CONTACT_ORG_NAME) like #search#  or 
 upper(t.TO_NAME_PINYIN) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

selectWin
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		(select count(1) from PUB_CONTACT_ALT a where a.is_use='Y' and a.WORKFLOW_STATUS=3 and a.CONTACT_ORG_ID=t.CONTACT_ORG_ID) as VERSION_NO,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		t.IS_INNER_ORG,
		t.TYPE,
		t.CONTACT_TYPE,
		t.INNER_ORG_ID ,
			TYPE.CONTACT_ORG_TYPE_NAME as  TYPE_NAME
	 @}
from PUB_CONTACT_ORG t 
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
where t.is_use = 'Y' 
 and t.WORKFLOW_STATUS = 3
 and t.type=#type#
@if(!isEmpty(contactOrgTypeId)){
 AND (t.contact_org_type_id = #contactOrgTypeId# or
            t.CONTACT_ORG_TYPE_ID in
           (with recursive tmp as 
(select A.CONTACT_ORG_TYPE_ID  from PUB_CONTACT_ORG_TYPE A where A.contact_org_type_pid = #contactOrgTypeId#
UNION ALL 
select B.CONTACT_ORG_TYPE_ID from PUB_CONTACT_ORG_TYPE B,tmp t  where t.CONTACT_ORG_TYPE_ID = B.CONTACT_ORG_TYPE_PID) 
select *  from tmp p))
@}

@if(!isEmpty(contactOrgTypeCode)){
	AND type.contact_org_type_code = #contactOrgTypeCode# 
@}            
@if(!isEmpty(pubContactOrgIds)){
	AND t.CONTACT_ORG_ID in (#join(pubContactOrgIds)#)
@} 
@if(!isEmpty(search)){
 and(
 upper(t.CONTACT_ORG_NAME) like #search#  or 
 upper(t.TO_NAME_PINYIN) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}


searchMulti
===
select getcontactorgname(#contactOrgIds#) from dual



selectBlockWin
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_TYPE,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		(select count(1) from PUB_CONTACT_ALT a where a.is_use='Y' and a.WORKFLOW_STATUS=3 and a.CONTACT_ORG_ID=t.CONTACT_ORG_ID) as VERSION_NO,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		t.IS_INNER_ORG,
		t.TYPE,
		t.INNER_ORG_ID
	 @}
from PUB_CONTACT_ORG t 
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
where t.is_use = 'Y' 
 and t.WORKFLOW_STATUS = 3
@if(!isEmpty(type)){
    @if('1'==type){
    and t.CONTACT_TYPE = '1'
    and t.TYPE = '1'
    @}
    @if('2'==type){
    and t.CONTACT_TYPE = '1'
    and t.TYPE = '2'
    @}
    @if('3'==type){
    and t.CONTACT_TYPE = '2'
    and t.TYPE = '1'
    @}
    @if('4'==type){
    and t.CONTACT_TYPE = '2'
    and t.TYPE = '2'
    @}
@}
@if(!isEmpty(search)){
 and(
 upper(t.CONTACT_ORG_NAME) like #search#  or 
 upper(t.TO_NAME_PINYIN) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}


pageContactOrg
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.ORG_TYPE,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		GETDICNAME('ORG_TYPE', t.ORG_TYPE) AS ORG_TYPE_TEXT,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		type.ORG_TYPE type_org_type,
		t.IS_INNER_ORG,
		t.TYPE,
		t.CONTACT_TYPE,
		GETDICNAME('CONTACT_TYPE',t.CONTACT_TYPE) AS CONTACT_TYPE_TEXT,
		t.INNER_ORG_ID
	 @}
from v_common_con p
LEFT JOIN PUB_CONTACT_ORG t 
on t.contact_Org_Id = p.PARTY_B
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
where t.is_use = 'Y' 
and p.con_id=#conId#



countContact
===
select count(1)
from v_common_con t
where (case
      when t.formcode='PmPmcon' then
                    t.party_b
      when t.formcode='PmBidSercon' then
                    t.party_b
      when t.formcode='ImInvconJJ' or t.formcode='ImInvconGQ' then
                    t.party_b
      end)=to_char(#id#)
      
selectNameById
=== 
 select 
t.CONTACT_ORG_NAME 
from 
PUB_CONTACT_ORG t 
where 
 t.IS_USE ='Y'
@if(!isEmpty(id)){
  and t.CONTACT_ORG_ID =(
     select 
     ci.ZL_LESSEE 
     from 
     con_info ci 
     where ci .CON_ID =#id#
     and ci .IS_USE ='Y'
  )
@}

getContractOrgByCon
===
select  @pageTag(){
    t.CONTACT_ORG_ID ,
    t.CONTACT_ORG_NAME ,
    t.CONTACT_ORG_CODE ,
    t.CONTACT_TEL
@}
from
    PUB_CONTACT_ORG t
where
    t.IS_USE = 'Y'
    and t.CONTACT_ORG_ID in (
    select
        co.ZL_LESSEE
    from
        con_info co
    where
        co.IS_USE = 'Y'
        and co.CON_TYPE = 126 )
@if(!isEmpty(search)){
    and t.CONTACT_ORG_NAME like #search#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}


getConByContractOrg
===
select
    co.CON_ID ID,
    co.CON_ID value,
    co.CON_NAME text
from
    con_info co
where
    co.IS_USE = 'Y'
    and co.CON_TYPE = 126
@if(!isEmpty(contractOrgId)){
    and co .ZL_LESSEE like #contractOrgId#
@}

==> fine-web-0.0.2-20220909.090829-172.jar: beetlsql/pub/PubContactOrg.md <==
select
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.ORG_TYPE,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		GETDICNAME('ORG_TYPE', t.ORG_TYPE) AS ORG_TYPE_TEXT,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		type.ORG_TYPE type_org_type,
		t.IS_INNER_ORG,
		t.TYPE,
		t.CONTACT_TYPE,
		GETDICNAME('CONTACT_TYPE',t.CONTACT_TYPE) AS CONTACT_TYPE_TEXT,
		t.INNER_ORG_ID,
		TYPE.CONTACT_ORG_TYPE_NAME as  TYPE_NAME 
	 @}
from PUB_CONTACT_ORG t
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
where t.is_use = 'Y'
 @if(!isEmpty(contactOrgTypeId)){
AND (t.contact_org_type_id = #contactOrgTypeId# or
            t.CONTACT_ORG_TYPE_ID in
           (with recursive tmp as 
(select A.CONTACT_ORG_TYPE_ID  from PUB_CONTACT_ORG_TYPE A where A.contact_org_type_pid = #contactOrgTypeId#
UNION ALL 
select B.CONTACT_ORG_TYPE_ID from PUB_CONTACT_ORG_TYPE B,tmp t  where t.CONTACT_ORG_TYPE_ID = B.CONTACT_ORG_TYPE_PID) 
select *  from tmp p))
@}
@if(!isEmpty(contactType)){
and t.CONTACT_TYPE =#contactType#
@}
@if(!isEmpty(search)){
and(
 upper(t.CONTACT_ORG_NAME) like #search#  or 
 upper(t.TO_NAME_PINYIN) like #search#   or 
 upper(t.ID_CARD) like #search#   or 
 upper(t.REGISTER_CAPITAL) like #search#   or 
 upper(t.CONTACT_ORG_CODE) like #search#  or 
 upper(t.legal_Person) like #search#  or 
 upper(t.org_Addr) like #search#  or 
 upper(t.business_Scope) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

selectWin
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		(select count(1) from PUB_CONTACT_ALT a where a.is_use='Y' and a.WORKFLOW_STATUS=3 and a.CONTACT_ORG_ID=t.CONTACT_ORG_ID) as VERSION_NO,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		t.IS_INNER_ORG,
		t.TYPE,
		t.CONTACT_TYPE,
		t.INNER_ORG_ID ,
			TYPE.CONTACT_ORG_TYPE_NAME as  TYPE_NAME
	 @}
from PUB_CONTACT_ORG t 
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
where t.is_use = 'Y' 
 and t.WORKFLOW_STATUS = 3
@if(!isEmpty(contactOrgTypeId)){
 AND (t.contact_org_type_id = #contactOrgTypeId# or
            t.CONTACT_ORG_TYPE_ID in
           (with recursive tmp as 
(select A.CONTACT_ORG_TYPE_ID  from PUB_CONTACT_ORG_TYPE A where A.contact_org_type_pid = #contactOrgTypeId#
UNION ALL 
select B.CONTACT_ORG_TYPE_ID from PUB_CONTACT_ORG_TYPE B,tmp t  where t.CONTACT_ORG_TYPE_ID = B.CONTACT_ORG_TYPE_PID) 
select *  from tmp p))
@}

@if(!isEmpty(contactOrgTypeCode)){
	AND type.contact_org_type_code = #contactOrgTypeCode# 
@}            
@if(!isEmpty(pubContactOrgIds)){
	AND t.CONTACT_ORG_ID in (#join(pubContactOrgIds)#)
@} 
@if(!isEmpty(search)){
 and(
 upper(t.CONTACT_ORG_NAME) like #search#  or 
 upper(t.TO_NAME_PINYIN) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}


searchMulti
===
select getcontactorgname(#contactOrgIds#) from dual



selectBlockWin
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_TYPE,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		(select count(1) from PUB_CONTACT_ALT a where a.is_use='Y' and a.WORKFLOW_STATUS=3 and a.CONTACT_ORG_ID=t.CONTACT_ORG_ID) as VERSION_NO,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		t.IS_INNER_ORG,
		t.TYPE,
		t.INNER_ORG_ID
	 @}
from PUB_CONTACT_ORG t 
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
where t.is_use = 'Y' 
 and t.WORKFLOW_STATUS = 3
@if(!isEmpty(type)){
    @if('1'==type){
    and t.CONTACT_TYPE = '1'
    and t.TYPE = '1'
    @}
    @if('2'==type){
    and t.CONTACT_TYPE = '1'
    and t.TYPE = '2'
    @}
    @if('3'==type){
    and t.CONTACT_TYPE = '2'
    and t.TYPE = '1'
    @}
    @if('4'==type){
    and t.CONTACT_TYPE = '2'
    and t.TYPE = '2'
    @}
@}
@if(!isEmpty(search)){
 and(
 upper(t.CONTACT_ORG_NAME) like #search#  or 
 upper(t.TO_NAME_PINYIN) like #search#  
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}


pageContactOrg
===
select @pageTag(){
				t.CONTACT_ORG_ID,
		t.CONTACT_ORG_TYPE_ID,
		t.CONTACT_ORG_NAME,
		t.CONTACT_ORG_CODE,
		t.TO_NAME_PINYIN,
		t.ORG_TYPE,
		t.LEGAL_PERSON,
		t.REGISTER_CAPITAL,
		t.FOUND_DATE,
		t.OPERATE_PERIOD_FROM,
		t.OPERATE_PERIOD_TO,
		t.REG_AUTHORITY,
		t.APPROVE_DATE,
		t.ORG_ADDR,
		t.INFO_URL,
		t.CONTACT_NAME,
		t.CONTACT_TEL,
		t.ID_CARD,
		t.REG_STATUS,
		t.BUSINESS_SCOPE,
		t.REMARK,
		t.IS_USE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.TO_FINANCE_CODE,
		GETDICNAME('ORG_TYPE', t.ORG_TYPE) AS ORG_TYPE_TEXT,
		t.PROCESSINSTID,
		t.WORKFLOW_STATUS,
		GETDICNAME('WORKFLOW_STATUS',t.WORKFLOW_STATUS) WORKFLOW_STATUS_TEXT,
		b.AREA_FULL_NAME,
		type.ORG_TYPE type_org_type,
		t.IS_INNER_ORG,
		t.TYPE,
		t.CONTACT_TYPE,
		GETDICNAME('CONTACT_TYPE',t.CONTACT_TYPE) AS CONTACT_TYPE_TEXT,
		t.INNER_ORG_ID
	 @}
from v_common_con p
LEFT JOIN PUB_CONTACT_ORG t 
on t.contact_Org_Id = p.PARTY_B
LEFT JOIN PUB_CONTACT_ORG_TYPE type
on type.contact_org_type_id = t.contact_org_type_id
LEFT JOIN PUB_AREA b ON b.AREA_ID = t.AREA_ID
where t.is_use = 'Y' 
and p.con_id=#conId#



countContact
===
select count(1)
from v_common_con t
where (case
      when t.formcode='PmPmcon' then
                    t.party_b
      when t.formcode='PmBidSercon' then
                    t.party_b
      when t.formcode='ImInvconJJ' or t.formcode='ImInvconGQ' then
                    t.party_b
      end)=to_char(#id#)
      
selectNameById
=== 
 select 
t.CONTACT_ORG_NAME 
from 
PUB_CONTACT_ORG t 
where 
 t.IS_USE ='Y'
@if(!isEmpty(id)){
  and t.CONTACT_ORG_ID =(
     select 
     ci.ZL_LESSEE 
     from 
     con_info ci 
     where ci .CON_ID =#id#
     and ci .IS_USE ='Y'
  )
@}

getContractOrgByCon
===
select  @pageTag(){
    t.CONTACT_ORG_ID ,
    t.CONTACT_ORG_NAME ,
    t.CONTACT_ORG_CODE ,
    t.CONTACT_TEL
@}
from
    PUB_CONTACT_ORG t
where
    t.IS_USE = 'Y'
    and t.CONTACT_ORG_ID in (
    select
        co.ZL_LESSEE
    from
        con_info co
    where
        co.IS_USE = 'Y'
        and co.CON_TYPE = 126 )
@if(!isEmpty(search)){
    and t.CONTACT_ORG_NAME like #search#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.CONTACT_ORG_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}


getConByContractOrg
===
select
    co.CON_ID ID,
    co.CON_ID value,
    co.CON_NAME text
from
    con_info co
where
    co.IS_USE = 'Y'
    and co.CON_TYPE = 126
@if(!isEmpty(contractOrgId)){
    and co .ZL_LESSEE like #contractOrgId#
@}
